/*------------------------------------------------------------------------
 *
 * File:        preamp.h
 *
 * Author:		Suzy Jackson <suzyj@littlefishbicycles.com>
 *
 * Revision:	0.1
 *
 * Commenced:	16 April 2006.
 *
 * Last edit:	2 May 2006.
 *
 * Purpose:     Main program header file.

/*------------------------------------------------------------------------
 *
 * VOLUME SET - Drives serial data lines on PGA2310 volume control.
 *
 *------------------------------------------------------------------------*/

void
volume_set(unsigned char right, unsigned char left);

/*------------------------------------------------------------------------
 *
 * ENCODER - Checks rotary encoder and returns the following:
 *
 *               0:  no movement
 *              -1:  ccw rotation
 *               1:  cw rotation
 *
 *------------------------------------------------------------------------*/

signed char
encoder(void);

/*------------------------------------------------------------------------
 *
 * RC5_RECEIVE - Checks IR receiver and returns the following:
 *
 *               0:  no meaningful IR data present
 *              !0:  14 bit RC5 packet
 *
 *------------------------------------------------------------------------*/

unsigned int
rc5_receive(void);

/*------------------------------------------------------------------------
 *
 * CHECK_SOURCE_PB - Checks source select pushbuttons and returns the following:
 *
 *               0xff:  no pushbutton pressed
 *               0x00:  source 1 pushbutton pressed
 *               ...
 *               0x07:  source 8 pushbutton pressed
 *
 *------------------------------------------------------------------------*/

unsigned char
check_source_pb(void);

/*------------------------------------------------------------------------
 *
 * RELAY_SET - Outputs data to the relay driver.  Inputs are:
 *
 *               0x00:  source 1 selected
 *               ...
 *               0x07:  source 8 selected
 *
 *------------------------------------------------------------------------*/

void
relay_set (unsigned char source);

/*------------------------------------------------------------------------
 *
 * VIDEO_SET - Outputs data to the video select board.  Inputs are:
 *
 *               0x00:  source 1 selected
 *               ...
 *               0x07:  source 8 selected
 *
 *------------------------------------------------------------------------*/

void
video_set (unsigned char source);

/*------------------------------------------------------------------------
 *
 * UPDATE_LEGENDS - displays the dB symbol and decimal point on the VFD.
 *
 *------------------------------------------------------------------------*/

void
update_legends(void);

/*------------------------------------------------------------------------
 *
 * UPDATE_SOURCE_DISPLAY - Displays thesource on the VFD.
 *
 *           Source selection:
 *               0x00:  "Tuner"
 *               0x01:  "TV"
 *               0x02:  "Phono"
 *               0x03:  "DVD"
 *               0x04:  "CD"
 *               0x05:  "VHS"
 *               0x06:  "Tape"
 *               0x07:  "HTPC"
 *
 *------------------------------------------------------------------------*/

void
update_source_display(unsigned char source);

/*------------------------------------------------------------------------
 *
 * UPDATE_VOLUME_DISPLAY - Displays the volume on the VFD.
 *
 *           Volume encoding:
 *               0x00:  "-96.0dB"
 *               0x01:  "-95.5dB"
 *               ...
 *               0xc0:  "+00.0dB"
 *               ...
 *               0xfe:  "+31.0dB"
 *               0xff:  "+31.5dB"
 *
 *------------------------------------------------------------------------*/

void
update_volume_display(unsigned char volume);

/*------------------------------------------------------------------------
 *
 * UPDATE_DISPLAY - displays the whole display.
 *
 *------------------------------------------------------------------------*/

void
update_display(unsigned char source, unsigned char volume);

